@@ -60,14 +60,32 @@ class KatDep(KatRes):
   # --
 
   def ternary_status(self):
-    statuses = [p.ternary_status() for p in self.pods()]
+    from k8kat.res.pod.kat_pod import KatPod
+    statuses = list(map(KatPod.ternary_status, self.pods()))
     if len(set(statuses)) == 1:
       return statuses[0]
-    # elif len(set(statuses)) > 1:
-    #   return 'negative' if 'negative' in statuses else 'pending'
+    elif len(set(statuses)) > 1:
+      statuses = list(map(KatPod.ternary_status, self.latest_gen_pods()))
+      return 'negative' if 'negative' in statuses else 'pending'
     else:
       return 'pending'
 
+  def latest_gen_pods(self) -> List:
+    from k8kat.res.pod.kat_pod import KatPod
+    pods: List[KatPod] = sorted(self.pods(), key=lambda p: p.created_at())
+    latest_generation_ts = datetime.min
+    latest_generation_pods = []
+
+    for i in range(len(pods)):
+      pod = pods[i]
+      if (pod.created_at() - latest_generation_ts).seconds > 3:
+        latest_generation_ts = pod.created_at()
+        latest_generation_pods = [pod]
+      else:
+        latest_generation_pods.append(pod)
+
+    return latest_generation_pods
+
   def is_running_normally(self):
     return self.ready_replicas == self.replica_count
 
