@@ -1,10 +1,10 @@
 from functools import lru_cache
 from http.client import HTTPResponse
-from typing import List, Optional, Callable, TypeVar, Any
+from typing import List, Optional, Callable, TypeVar, Any, Dict
 
 from kubernetes import stream as k8s_streaming
 from kubernetes.client import V1Pod, V1Container, \
-  V1ContainerState, V1PodCondition
+  V1ContainerState, V1PodCondition, V1ContainerStatus
 from kubernetes.client.rest import ApiException
 
 from k8kat.auth.kube_broker import broker
@@ -331,6 +331,23 @@ class KatPod(KatRes):
         ))
     return intel
 
+  def main_container_status_summaries(self) -> List[Dict]:
+    summaries = []
+
+    def extract(cont_status: V1ContainerStatus):
+      try_states = ['running', 'waiting', 'terminated']
+      tester = lambda try_state: getattr(cont_status.state, try_state[1])
+      tup = next(filter(tester, enumerate(try_states)), None)
+      return try_states[tup[0]] if tup else None
+
+    for state in self.body().status.container_statuses:
+      summaries.append({
+        'name': state.name,
+        'status': extract(state)
+      })
+
+    return summaries
+
   def container_status_intel(self):
     bad_states: List[V1ContainerState] = self.filter_container_states([
       *self.init_container_states(),
