@@ -1,5 +1,5 @@
 import traceback
-from typing import Dict, Optional
+from typing import Dict, Optional, List
 
 from kubernetes.client import V1ServicePort, V1Service
 from kubernetes.client.rest import ApiException
@@ -7,6 +7,8 @@ from kubernetes.client.rest import ApiException
 from k8kat.auth.kube_broker import broker
 from k8kat.res.base import rest_backend
 from k8kat.res.base.kat_res import KatRes
+from k8kat.res.pod.kat_pod import KP
+from k8kat.res.relation.relation import Relation
 from k8kat.utils.main import utils
 from k8kat.utils.main.class_property import classproperty
 
@@ -47,7 +49,6 @@ class KatSvc(KatRes):
     port_obj = next(filter(tcp_finder, self.body().spec.ports), None)
     return port_obj.port if port_obj else None
 
-
   @property
   def main_port_obj(self) -> V1ServicePort:
     ports = self.raw.spec.ports
@@ -104,3 +105,21 @@ class KatSvc(KatRes):
   @property
   def endpoint_ips(self):
     return [ep.ip for ep in self.flat_endpoints()]
+
+  # --
+  # --
+  # --
+  # -------------------------------RELATIONS-------------------------------
+  # --
+  # --
+  # --
+
+  def pods(self, **query) -> List[KP]:
+    """Selects and returns pods associated with the deployment."""
+    from k8kat.res.pod.kat_pod import KatPod
+    return Relation[KatPod](
+      model_class=KatPod,
+      ns=self.ns,
+      labels=self.pod_select_labels,
+      **query
+    )
